<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Fluxbox’ı Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Restart IceWM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart JWM</source>
        <translation>Yeniden Başlat JWM</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Log Out</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="42"/>
        <source>Shutdown</source>
        <translation>Bilgisayarı Kapat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Çıkış seçenekleriyle MX Fluxbox için pop-up</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>Düğmeleri dikey bir pencerede göster</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Düğmeleri yatay bir pencerede göster</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>Saniye olarak zaman aşımı süresi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>düğmeleri dikey olarak kullanmak için -v veya --vertical’ı kullanın
düğmeleri yatay olarak kullanmak için -h veya --horizontal’ı kullanın</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Kullanım: exit-options [seçenekler]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>Seçenekler:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, --horizontal	 Düğmeleri yatay olarak göstermek için bir seçenek</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>-v, --vertical	 Düğmeleri dikey olarak göstermek için bir seçenek</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, --timeout &lt;sec&gt;	 Saniye cinsinden zaman aşımı süresi
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Kullanılan ekran yönü seçeneği, uygulamayı bir sonraki başlatışınızda hatırlanacak ve kullanılacaktır.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternatif olarak, ~/.config/MX-Linux/exit-options.conf dosyasında ‘layout=horizontal’ veya ‘layout=vertical’ seçeneğini ayarlayın.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>exit-options.conf’ta zaman aşımını ayarlamak için ‘timeout=X’ kullanın; burada X, saniye cinsinden zaman aşımıdır.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Exit-options.conf dosyasına IconName=/yol/simgeadı.uzantı ekleyerek özel simgeler tanımlayabilirsiniz. Yeniden eşlediğiniz simgelerin adları: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>exit-options.conf dosyasında ayarlanabilen diğer seçenekler: %1</translation>
    </message>
</context>
</TS>